"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _LogErrorVerbosity:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LogErrorVerbosityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LogErrorVerbosity.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LOG_ERROR_VERBOSITY_UNSPECIFIED: _LogErrorVerbosity.ValueType  # 0
    TERSE: _LogErrorVerbosity.ValueType  # 1
    DEFAULT: _LogErrorVerbosity.ValueType  # 2
    VERBOSE: _LogErrorVerbosity.ValueType  # 3

class LogErrorVerbosity(_LogErrorVerbosity, metaclass=_LogErrorVerbosityEnumTypeWrapper): ...

LOG_ERROR_VERBOSITY_UNSPECIFIED: LogErrorVerbosity.ValueType  # 0
TERSE: LogErrorVerbosity.ValueType  # 1
DEFAULT: LogErrorVerbosity.ValueType  # 2
VERBOSE: LogErrorVerbosity.ValueType  # 3
global___LogErrorVerbosity = LogErrorVerbosity

class _LogLevelMessage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LogLevelMessageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LogLevelMessage.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LOG_LEVEL_MESSAGE_UNSPECIFIED: _LogLevelMessage.ValueType  # 0
    DEBUG5: _LogLevelMessage.ValueType  # 1
    DEBUG4: _LogLevelMessage.ValueType  # 2
    DEBUG3: _LogLevelMessage.ValueType  # 3
    DEBUG2: _LogLevelMessage.ValueType  # 4
    DEBUG1: _LogLevelMessage.ValueType  # 5
    INFO: _LogLevelMessage.ValueType  # 6
    NOTICE: _LogLevelMessage.ValueType  # 7
    WARNING: _LogLevelMessage.ValueType  # 8
    ERROR: _LogLevelMessage.ValueType  # 9
    FATAL: _LogLevelMessage.ValueType  # 10
    PANIC: _LogLevelMessage.ValueType  # 11

class LogLevelMessage(_LogLevelMessage, metaclass=_LogLevelMessageEnumTypeWrapper): ...

LOG_LEVEL_MESSAGE_UNSPECIFIED: LogLevelMessage.ValueType  # 0
DEBUG5: LogLevelMessage.ValueType  # 1
DEBUG4: LogLevelMessage.ValueType  # 2
DEBUG3: LogLevelMessage.ValueType  # 3
DEBUG2: LogLevelMessage.ValueType  # 4
DEBUG1: LogLevelMessage.ValueType  # 5
INFO: LogLevelMessage.ValueType  # 6
NOTICE: LogLevelMessage.ValueType  # 7
WARNING: LogLevelMessage.ValueType  # 8
ERROR: LogLevelMessage.ValueType  # 9
FATAL: LogLevelMessage.ValueType  # 10
PANIC: LogLevelMessage.ValueType  # 11
global___LogLevelMessage = LogLevelMessage

class _LogStatement:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LogStatementEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LogStatement.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LOG_STATEMENT_UNSPECIFIED: _LogStatement.ValueType  # 0
    """LogStatement not explicitly set (uses defaults)."""
    NONE: _LogStatement.ValueType  # 1
    """None statements are logged."""
    DDL: _LogStatement.ValueType  # 2
    """Logs all data definition commands like `CREATE`, `ALTER`, and `DROP`. Default value."""
    MOD: _LogStatement.ValueType  # 3
    """Logs all `DDL` statements, plus `INSERT`, `UPDATE`, `DELETE`, `TRUNCATE`, and `COPY FROM`."""
    ALL: _LogStatement.ValueType  # 4
    """Logs all statements."""

class LogStatement(_LogStatement, metaclass=_LogStatementEnumTypeWrapper): ...

LOG_STATEMENT_UNSPECIFIED: LogStatement.ValueType  # 0
"""LogStatement not explicitly set (uses defaults)."""
NONE: LogStatement.ValueType  # 1
"""None statements are logged."""
DDL: LogStatement.ValueType  # 2
"""Logs all data definition commands like `CREATE`, `ALTER`, and `DROP`. Default value."""
MOD: LogStatement.ValueType  # 3
"""Logs all `DDL` statements, plus `INSERT`, `UPDATE`, `DELETE`, `TRUNCATE`, and `COPY FROM`."""
ALL: LogStatement.ValueType  # 4
"""Logs all statements."""
global___LogStatement = LogStatement

class _GPAutostatsMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GPAutostatsModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GPAutostatsMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GP_AUTOSTATS_MODE_UNSPECIFIED: _GPAutostatsMode.ValueType  # 0
    """GPAutostatsMode not explicitly set (uses defaults)."""
    GP_AUTOSTATS_MODE_NONE: _GPAutostatsMode.ValueType  # 1
    """Disable auto-ANALYZE completely. Stats will be updated only via manual ANALYZE calls."""
    GP_AUTOSTATS_MODE_ON_CHANGE: _GPAutostatsMode.ValueType  # 2
    """Run ANALYZE when data changes exceed threshold (e.g., after INSERT/UPDATE/DELETE)."""
    GP_AUTOSTATS_MODE_ON_NO_STATS: _GPAutostatsMode.ValueType  # 3
    """Run ANALYZE only if no stats exist (e.g., new or cleared table)."""

class GPAutostatsMode(_GPAutostatsMode, metaclass=_GPAutostatsModeEnumTypeWrapper):
    """Specifies the mode for triggering automatic statistics collection with ANALYZE.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_autostats_mode
    """

GP_AUTOSTATS_MODE_UNSPECIFIED: GPAutostatsMode.ValueType  # 0
"""GPAutostatsMode not explicitly set (uses defaults)."""
GP_AUTOSTATS_MODE_NONE: GPAutostatsMode.ValueType  # 1
"""Disable auto-ANALYZE completely. Stats will be updated only via manual ANALYZE calls."""
GP_AUTOSTATS_MODE_ON_CHANGE: GPAutostatsMode.ValueType  # 2
"""Run ANALYZE when data changes exceed threshold (e.g., after INSERT/UPDATE/DELETE)."""
GP_AUTOSTATS_MODE_ON_NO_STATS: GPAutostatsMode.ValueType  # 3
"""Run ANALYZE only if no stats exist (e.g., new or cleared table)."""
global___GPAutostatsMode = GPAutostatsMode

@typing.final
class Resources(google.protobuf.message.Message):
    """A list of computational resources allocated to a host."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources allocated to a host.

    Available presets are listed in the [documentation](/docs/managed-greenplum/concepts/instance-types).
    """
    disk_size: builtins.int
    """Volume of the storage used by the host, in bytes."""
    disk_type_id: builtins.str
    """Type of the storage used by the host: `network-hdd`, `network-ssd` or `local-ssd`."""
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
        disk_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "disk_type_id", b"disk_type_id", "resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources

@typing.final
class ConnectionPoolerConfig(google.protobuf.message.Message):
    """Route server configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PoolMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PoolModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ConnectionPoolerConfig._PoolMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        POOL_MODE_UNSPECIFIED: ConnectionPoolerConfig._PoolMode.ValueType  # 0
        """PoolMode not explicitly set (uses defaults)."""
        SESSION: ConnectionPoolerConfig._PoolMode.ValueType  # 1
        """Assign server connection to a client until it disconnects. Default value."""
        TRANSACTION: ConnectionPoolerConfig._PoolMode.ValueType  # 2
        """Assign server connection to a client for a transaction processing."""

    class PoolMode(_PoolMode, metaclass=_PoolModeEnumTypeWrapper):
        """Route server pool mode."""

    POOL_MODE_UNSPECIFIED: ConnectionPoolerConfig.PoolMode.ValueType  # 0
    """PoolMode not explicitly set (uses defaults)."""
    SESSION: ConnectionPoolerConfig.PoolMode.ValueType  # 1
    """Assign server connection to a client until it disconnects. Default value."""
    TRANSACTION: ConnectionPoolerConfig.PoolMode.ValueType  # 2
    """Assign server connection to a client for a transaction processing."""

    MODE_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    CLIENT_IDLE_TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_TIMEOUT_FIELD_NUMBER: builtins.int
    mode: global___ConnectionPoolerConfig.PoolMode.ValueType
    """Route server pool mode."""
    @property
    def size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of servers in the server pool. Clients are placed in a wait queue when all servers are busy.

        Set to zero to disable the limit.
        """

    @property
    def client_idle_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Client pool idle timeout, in seconds.

        Drop stale client connection after this much seconds of idleness, which is not in transaction.

        Set to zero to disable.
        """

    @property
    def idle_in_transaction_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Client pool idle in transaction timeout, in seconds.

        Drop client connection in transaction after this much seconds of idleness.

        Set to zero to disable.
        """

    def __init__(
        self,
        *,
        mode: global___ConnectionPoolerConfig.PoolMode.ValueType = ...,
        size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        client_idle_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        idle_in_transaction_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["client_idle_timeout", b"client_idle_timeout", "idle_in_transaction_timeout", b"idle_in_transaction_timeout", "size", b"size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["client_idle_timeout", b"client_idle_timeout", "idle_in_transaction_timeout", b"idle_in_transaction_timeout", "mode", b"mode", "size", b"size"]) -> None: ...

global___ConnectionPoolerConfig = ConnectionPoolerConfig

@typing.final
class BackgroundActivityStartAt(google.protobuf.message.Message):
    """Start time for background activity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOURS_FIELD_NUMBER: builtins.int
    MINUTES_FIELD_NUMBER: builtins.int
    hours: builtins.int
    """hours"""
    minutes: builtins.int
    """minutes"""
    def __init__(
        self,
        *,
        hours: builtins.int = ...,
        minutes: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hours", b"hours", "minutes", b"minutes"]) -> None: ...

global___BackgroundActivityStartAt = BackgroundActivityStartAt

@typing.final
class TableSizes(google.protobuf.message.Message):
    """Enables scripts that collects tables sizes to `*_sizes` tables in `mdb_toolkit` schema."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STARTS_FIELD_NUMBER: builtins.int
    @property
    def starts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BackgroundActivityStartAt]:
        """Time when start "table_sizes" script"""

    def __init__(
        self,
        *,
        starts: collections.abc.Iterable[global___BackgroundActivityStartAt] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["starts", b"starts"]) -> None: ...

global___TableSizes = TableSizes

@typing.final
class AnalyzeAndVacuum(google.protobuf.message.Message):
    """Configuration for `ANALYZE` and `VACUUM` operations."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_FIELD_NUMBER: builtins.int
    ANALYZE_TIMEOUT_FIELD_NUMBER: builtins.int
    VACUUM_TIMEOUT_FIELD_NUMBER: builtins.int
    @property
    def start(self) -> global___BackgroundActivityStartAt:
        """Time when analyze will start"""

    @property
    def analyze_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum duration of the `ANALYZE` operation, in seconds. The default value is `36000`. As soon as this period expires, the `ANALYZE` operation will be forced to terminate."""

    @property
    def vacuum_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum duration of the `VACUUM` operation, in seconds. The default value is `36000`. As soon as this period expires, the `VACUUM` operation will be forced to terminate."""

    def __init__(
        self,
        *,
        start: global___BackgroundActivityStartAt | None = ...,
        analyze_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        vacuum_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["analyze_timeout", b"analyze_timeout", "start", b"start", "vacuum_timeout", b"vacuum_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["analyze_timeout", b"analyze_timeout", "start", b"start", "vacuum_timeout", b"vacuum_timeout"]) -> None: ...

global___AnalyzeAndVacuum = AnalyzeAndVacuum

@typing.final
class BackgroundActivitiesConfig(google.protobuf.message.Message):
    """Configuration for long running queries killer."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_SIZES_FIELD_NUMBER: builtins.int
    ANALYZE_AND_VACUUM_FIELD_NUMBER: builtins.int
    QUERY_KILLER_SCRIPTS_FIELD_NUMBER: builtins.int
    @property
    def table_sizes(self) -> global___TableSizes:
        """Enables scripts that collects tables sizes to `*_sizes` tables in `mdb_toolkit` schema."""

    @property
    def analyze_and_vacuum(self) -> global___AnalyzeAndVacuum:
        """Configuration for `ANALYZE` and `VACUUM` operations."""

    @property
    def query_killer_scripts(self) -> global___QueryKillerScripts:
        """Configuration for long running queries killer."""

    def __init__(
        self,
        *,
        table_sizes: global___TableSizes | None = ...,
        analyze_and_vacuum: global___AnalyzeAndVacuum | None = ...,
        query_killer_scripts: global___QueryKillerScripts | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["analyze_and_vacuum", b"analyze_and_vacuum", "query_killer_scripts", b"query_killer_scripts", "table_sizes", b"table_sizes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["analyze_and_vacuum", b"analyze_and_vacuum", "query_killer_scripts", b"query_killer_scripts", "table_sizes", b"table_sizes"]) -> None: ...

global___BackgroundActivitiesConfig = BackgroundActivitiesConfig

@typing.final
class QueryKiller(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    IGNORE_USERS_FIELD_NUMBER: builtins.int
    @property
    def enable(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Use query killer or not"""

    @property
    def max_age(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum duration for this type of queries (in seconds)."""

    @property
    def ignore_users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Ignore these users when considering queries to terminate"""

    def __init__(
        self,
        *,
        enable: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_age: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ignore_users: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["enable", b"enable", "max_age", b"max_age"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["enable", b"enable", "ignore_users", b"ignore_users", "max_age", b"max_age"]) -> None: ...

global___QueryKiller = QueryKiller

@typing.final
class QueryKillerScripts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDLE_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_FIELD_NUMBER: builtins.int
    LONG_RUNNING_FIELD_NUMBER: builtins.int
    @property
    def idle(self) -> global___QueryKiller:
        """Configuration of script that kills long running queries that are in `idle` state."""

    @property
    def idle_in_transaction(self) -> global___QueryKiller:
        """Configuration of script that kills long running queries that are in `idle in transaction` state."""

    @property
    def long_running(self) -> global___QueryKiller:
        """Configuration of script that kills long running queries (in any state)."""

    def __init__(
        self,
        *,
        idle: global___QueryKiller | None = ...,
        idle_in_transaction: global___QueryKiller | None = ...,
        long_running: global___QueryKiller | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["idle", b"idle", "idle_in_transaction", b"idle_in_transaction", "long_running", b"long_running"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["idle", b"idle", "idle_in_transaction", b"idle_in_transaction", "long_running", b"long_running"]) -> None: ...

global___QueryKillerScripts = QueryKillerScripts

@typing.final
class MasterSubclusterConfig(google.protobuf.message.Message):
    """Configuration of the master subcluster."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> global___Resources:
        """Computational resources allocated to Greenplum® master subcluster hosts."""

    def __init__(
        self,
        *,
        resources: global___Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

global___MasterSubclusterConfig = MasterSubclusterConfig

@typing.final
class SegmentSubclusterConfig(google.protobuf.message.Message):
    """Configuration of the segment subcluster."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> global___Resources:
        """Computational resources allocated to Greenplum® segment subcluster hosts."""

    def __init__(
        self,
        *,
        resources: global___Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

global___SegmentSubclusterConfig = SegmentSubclusterConfig

@typing.final
class GreenplumConfig6(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_SLOT_WAL_KEEP_SIZE_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_SEGMENT_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_QUERY_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_FILES_PER_QUERY_FIELD_NUMBER: builtins.int
    MAX_PREPARED_TRANSACTIONS_FIELD_NUMBER: builtins.int
    GP_WORKFILE_COMPRESSION_FIELD_NUMBER: builtins.int
    MAX_STATEMENT_MEM_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_FIELD_NUMBER: builtins.int
    GP_ADD_COLUMN_INHERITS_TABLE_SETTING_FIELD_NUMBER: builtins.int
    GP_ENABLE_GLOBAL_DEADLOCK_DETECTOR_FIELD_NUMBER: builtins.int
    GP_GLOBAL_DEADLOCK_DETECTOR_PERIOD_FIELD_NUMBER: builtins.int
    GP_MAX_SLICES_FIELD_NUMBER: builtins.int
    GP_CACHED_SEGWORKERS_THRESHOLD_FIELD_NUMBER: builtins.int
    LOCK_TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_SESSION_TIMEOUT_FIELD_NUMBER: builtins.int
    RUNAWAY_DETECTOR_ACTIVATION_PERCENT_FIELD_NUMBER: builtins.int
    GP_VMEM_PROTECT_SEGWORKER_CACHE_LIMIT_FIELD_NUMBER: builtins.int
    GP_ENABLE_ZSTD_MEMORY_ACCOUNTING_FIELD_NUMBER: builtins.int
    GP_MAX_PLAN_SIZE_FIELD_NUMBER: builtins.int
    GP_AUTOSTATS_MODE_FIELD_NUMBER: builtins.int
    GP_AUTOSTATS_ON_CHANGE_THRESHOLD_FIELD_NUMBER: builtins.int
    GP_RESOURCE_GROUP_MEMORY_LIMIT_FIELD_NUMBER: builtins.int
    LOG_CONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_DISCONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_HOSTNAME_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_STATS_FIELD_NUMBER: builtins.int
    LOG_MIN_DURATION_STATEMENT_FIELD_NUMBER: builtins.int
    MASTER_SHARED_BUFFERS_FIELD_NUMBER: builtins.int
    MAX_LOCKS_PER_TRANSACTION_FIELD_NUMBER: builtins.int
    SEGMENT_SHARED_BUFFERS_FIELD_NUMBER: builtins.int
    LOG_ERROR_VERBOSITY_FIELD_NUMBER: builtins.int
    LOG_MIN_MESSAGES_FIELD_NUMBER: builtins.int
    log_statement: global___LogStatement.ValueType
    """Controls which SQL statements are logged. DDL logs all data definition commands like CREATE, ALTER, and DROP commands.
    MOD logs all DDL statements, plus INSERT, UPDATE, DELETE, TRUNCATE, and COPY FROM.
    PREPARE and EXPLAIN ANALYZE statements are also logged if their contained command is of an appropriate type.
    https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#log_statement
    Default value is ddl
    """
    gp_autostats_mode: global___GPAutostatsMode.ValueType
    """Specifies the mode for triggering automatic statistics collection after DML.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_autostats_mode
    """
    log_error_verbosity: global___LogErrorVerbosity.ValueType
    """Controls the amount of detail written in the server log for each message that is logged.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_error_verbosity
    """
    log_min_messages: global___LogLevelMessage.ValueType
    """Controls which message levels are written to the server log.
    Each level includes all the levels that follow it. The later the level, the fewer messages are sent to the log.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_min_messages
    """
    @property
    def max_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of inbound connections on master segment"""

    @property
    def max_slot_wal_keep_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specify the maximum size of WAL files that replication slots are allowed to retain in the pg_wal directory at checkpoint time.
        https://www.postgresql.org/docs/current/runtime-config-replication.html
        """

    @property
    def gp_workfile_limit_per_segment(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum total disk size that all running queries are allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#gp_workfile_limit_per_segment
        """

    @property
    def gp_workfile_limit_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum disk size an individual query is allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#gp_workfile_limit_per_query
        """

    @property
    def gp_workfile_limit_files_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of temporary spill files (also known as workfiles) allowed per query per segment.
        Spill files are created when executing a query that requires more memory than it is allocated.
        The current query is terminated when the limit is exceeded.
        Set the value to 0 (zero) to allow an unlimited number of spill files. master session reload
        https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#gp_workfile_limit_files_per_query
        Default value is 10000
        """

    @property
    def max_prepared_transactions(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of transactions that can be in the "prepared" state simultaneously
        https://www.postgresql.org/docs/9.6/runtime-config-resource.html
        """

    @property
    def gp_workfile_compression(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Specifies whether the temporary files created, when a hash aggregation or hash join operation spills to disk, are compressed.
        https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#gp_workfile_compression
        """

    @property
    def max_statement_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum memory limit for a query. Helps avoid out-of-memory errors on a segment host during query processing as a result of setting statement_mem too high.
        Taking into account the configuration of a single segment host, calculate max_statement_mem as follows:
        (seghost_physical_memory) / (average_number_concurrent_queries)
        When changing both max_statement_mem and statement_mem, max_statement_mem must be changed first, or listed first in the postgresql.conf file.
        https://greenplum.docs.pivotal.io/6-19/ref_guide/config_params/guc-list.html#max_statement_mem
        Default value is 2097152000 (2000MB)
        in bytes
        """

    @property
    def gp_add_column_inherits_table_setting(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_add_column_inherits_table_setting"""

    @property
    def gp_enable_global_deadlock_detector(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Controls whether the Greenplum Database Global Deadlock Detector is enabled to manage concurrent UPDATE and DELETE operations on heap tables to improve performance. See Inserting, Updating, and Deleting Datain the Greenplum Database Administrator Guide. The default is off, the Global Deadlock Detector is deactivated.
        If the Global Deadlock Detector is deactivated (the default), Greenplum Database runs concurrent update and delete operations on a heap table serially.
        If the Global Deadlock Detector is enabled, concurrent updates are permitted and the Global Deadlock Detector determines when a deadlock exists, and breaks the deadlock by cancelling one or more backend processes associated with the youngest transaction(s) involved.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_enable_global_deadlock_detector
        """

    @property
    def gp_global_deadlock_detector_period(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the executing interval (in seconds) of the global deadlock detector background worker process.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_global_deadlock_detector_period
        """

    @property
    def gp_max_slices(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max amount of slice-processes for one query in one segment.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_max_slices
        """

    @property
    def gp_cached_segworkers_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Define amount of working processes in segment, that keeping in warm cash after end of query for usage again in next queries.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_cached_segworkers_threshold
        """

    @property
    def lock_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max time (in ms) which query will wait lock free on object
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#lock_timeout
        """

    @property
    def idle_in_transaction_session_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max time (in ms) which session can idle in open transaction
        https://postgrespro.ru/docs/postgrespro/current/runtime-config-client#GUC-IDLE-IN-TRANSACTION-SESSION-TIMEOUT
        """

    @property
    def runaway_detector_activation_percent(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Percent of utilized Greenplum Database vmem that triggers the termination of queries.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#runaway_detector_activation_percent
        """

    @property
    def gp_vmem_protect_segworker_cache_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Set memory limit (in MB) for working process. If a query executor process consumes more than this configured amount, then the process will not be cached for use in subsequent queries after the process completes.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_vmem_protect_segworker_cache_limit
        """

    @property
    def gp_enable_zstd_memory_accounting(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Forces ZSTD lib use Greenplum memory allocation system."""

    @property
    def gp_max_plan_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the total maximum uncompressed size of a query execution plan multiplied by the number of Motion operators (slices) in the plan.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_max_plan_size
        """

    @property
    def gp_autostats_on_change_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the threshold for automatic statistics collection when gp_autostats_mode is set to on_change.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_autostats_on_change_threshold
        """

    @property
    def gp_resource_group_memory_limit(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """Identifies the maximum percentage of system memory resources to allocate to resource groups on each Greenplum Database segment node.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_resource_group_memory_limit
        """

    @property
    def log_connections(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """This outputs a line to the server log detailing each successful connection. Some client programs, like psql,
        attempt to connect twice while determining if a password is required, so duplicate "connection received" messages
        do not always indicate a problem.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_connections
        """

    @property
    def log_disconnections(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """This outputs a line in the server log at termination of a client session, and includes the duration of the session.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_disconnections
        """

    @property
    def log_hostname(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """By default, connection log messages only show the IP address of the connecting host.
        Turning on this option causes logging of the host name as well. Note that depending on your host name
        resolution setup this might impose a non-negligible performance penalty.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_hostname
        """

    @property
    def log_statement_stats(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """For each query, write total performance statistics of the query parser, planner, and executor to the server log.
        This is a crude profiling instrument.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_statement_stats
        """

    @property
    def log_min_duration_statement(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Logs the statement and its duration on a single log line if its duration is greater than or equal
        to the specified number of milliseconds. Setting this to 0 will print all statements and their durations.
        -1 deactivates the feature. For example, if you set it to 250 then all SQL statements that run 250ms or longer will be logged.
        Enabling this option can be useful in tracking down unoptimized queries in your applications.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_min_duration_statement
        in milliseconds.
        """

    @property
    def master_shared_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the amount of memory a Greenplum Database master instance uses for shared memory buffers.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#shared_buffers
        """

    @property
    def max_locks_per_transaction(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The shared lock table is created with room to describe locks on max_locks_per_transaction * (max_connections + max_prepared_transactions) objects,
        so no more than this many distinct objects can be locked at any one time.
        This is not a hard limit on the number of locks taken by any one transaction, but rather a maximum average value.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#max_locks_per_transaction
        """

    @property
    def segment_shared_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the amount of memory a Greenplum Database segment instance uses for shared memory buffers.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#shared_buffers
        """

    def __init__(
        self,
        *,
        max_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_slot_wal_keep_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_segment: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_files_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_prepared_transactions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_compression: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_statement_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_statement: global___LogStatement.ValueType = ...,
        gp_add_column_inherits_table_setting: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        gp_enable_global_deadlock_detector: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        gp_global_deadlock_detector_period: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_max_slices: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_cached_segworkers_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        lock_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        idle_in_transaction_session_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        runaway_detector_activation_percent: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_vmem_protect_segworker_cache_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_enable_zstd_memory_accounting: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        gp_max_plan_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_autostats_mode: global___GPAutostatsMode.ValueType = ...,
        gp_autostats_on_change_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_resource_group_memory_limit: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        log_connections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_disconnections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_hostname: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_statement_stats: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_min_duration_statement: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        master_shared_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_locks_per_transaction: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        segment_shared_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_error_verbosity: global___LogErrorVerbosity.ValueType = ...,
        log_min_messages: global___LogLevelMessage.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["gp_add_column_inherits_table_setting", b"gp_add_column_inherits_table_setting", "gp_autostats_on_change_threshold", b"gp_autostats_on_change_threshold", "gp_cached_segworkers_threshold", b"gp_cached_segworkers_threshold", "gp_enable_global_deadlock_detector", b"gp_enable_global_deadlock_detector", "gp_enable_zstd_memory_accounting", b"gp_enable_zstd_memory_accounting", "gp_global_deadlock_detector_period", b"gp_global_deadlock_detector_period", "gp_max_plan_size", b"gp_max_plan_size", "gp_max_slices", b"gp_max_slices", "gp_resource_group_memory_limit", b"gp_resource_group_memory_limit", "gp_vmem_protect_segworker_cache_limit", b"gp_vmem_protect_segworker_cache_limit", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "lock_timeout", b"lock_timeout", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_hostname", b"log_hostname", "log_min_duration_statement", b"log_min_duration_statement", "log_statement_stats", b"log_statement_stats", "master_shared_buffers", b"master_shared_buffers", "max_connections", b"max_connections", "max_locks_per_transaction", b"max_locks_per_transaction", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem", "runaway_detector_activation_percent", b"runaway_detector_activation_percent", "segment_shared_buffers", b"segment_shared_buffers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["gp_add_column_inherits_table_setting", b"gp_add_column_inherits_table_setting", "gp_autostats_mode", b"gp_autostats_mode", "gp_autostats_on_change_threshold", b"gp_autostats_on_change_threshold", "gp_cached_segworkers_threshold", b"gp_cached_segworkers_threshold", "gp_enable_global_deadlock_detector", b"gp_enable_global_deadlock_detector", "gp_enable_zstd_memory_accounting", b"gp_enable_zstd_memory_accounting", "gp_global_deadlock_detector_period", b"gp_global_deadlock_detector_period", "gp_max_plan_size", b"gp_max_plan_size", "gp_max_slices", b"gp_max_slices", "gp_resource_group_memory_limit", b"gp_resource_group_memory_limit", "gp_vmem_protect_segworker_cache_limit", b"gp_vmem_protect_segworker_cache_limit", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "lock_timeout", b"lock_timeout", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_error_verbosity", b"log_error_verbosity", "log_hostname", b"log_hostname", "log_min_duration_statement", b"log_min_duration_statement", "log_min_messages", b"log_min_messages", "log_statement", b"log_statement", "log_statement_stats", b"log_statement_stats", "master_shared_buffers", b"master_shared_buffers", "max_connections", b"max_connections", "max_locks_per_transaction", b"max_locks_per_transaction", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem", "runaway_detector_activation_percent", b"runaway_detector_activation_percent", "segment_shared_buffers", b"segment_shared_buffers"]) -> None: ...

global___GreenplumConfig6 = GreenplumConfig6

@typing.final
class GreenplumConfigCBDB(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_SLOT_WAL_KEEP_SIZE_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_SEGMENT_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_QUERY_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_FILES_PER_QUERY_FIELD_NUMBER: builtins.int
    MAX_PREPARED_TRANSACTIONS_FIELD_NUMBER: builtins.int
    GP_WORKFILE_COMPRESSION_FIELD_NUMBER: builtins.int
    MAX_STATEMENT_MEM_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_FIELD_NUMBER: builtins.int
    GP_ENABLE_GLOBAL_DEADLOCK_DETECTOR_FIELD_NUMBER: builtins.int
    GP_GLOBAL_DEADLOCK_DETECTOR_PERIOD_FIELD_NUMBER: builtins.int
    GP_MAX_SLICES_FIELD_NUMBER: builtins.int
    GP_CACHED_SEGWORKERS_THRESHOLD_FIELD_NUMBER: builtins.int
    LOCK_TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_SESSION_TIMEOUT_FIELD_NUMBER: builtins.int
    RUNAWAY_DETECTOR_ACTIVATION_PERCENT_FIELD_NUMBER: builtins.int
    GP_VMEM_PROTECT_SEGWORKER_CACHE_LIMIT_FIELD_NUMBER: builtins.int
    GP_ENABLE_ZSTD_MEMORY_ACCOUNTING_FIELD_NUMBER: builtins.int
    GP_MAX_PLAN_SIZE_FIELD_NUMBER: builtins.int
    GP_AUTOSTATS_MODE_FIELD_NUMBER: builtins.int
    GP_AUTOSTATS_ON_CHANGE_THRESHOLD_FIELD_NUMBER: builtins.int
    GP_RESOURCE_GROUP_MEMORY_LIMIT_FIELD_NUMBER: builtins.int
    LOG_CONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_DISCONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_HOSTNAME_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_STATS_FIELD_NUMBER: builtins.int
    LOG_MIN_DURATION_STATEMENT_FIELD_NUMBER: builtins.int
    MASTER_SHARED_BUFFERS_FIELD_NUMBER: builtins.int
    MAX_LOCKS_PER_TRANSACTION_FIELD_NUMBER: builtins.int
    SEGMENT_SHARED_BUFFERS_FIELD_NUMBER: builtins.int
    LOG_ERROR_VERBOSITY_FIELD_NUMBER: builtins.int
    LOG_MIN_MESSAGES_FIELD_NUMBER: builtins.int
    log_statement: global___LogStatement.ValueType
    """Controls which SQL statements are logged. DDL logs all data definition commands like CREATE, ALTER, and DROP commands.
    MOD logs all DDL statements, plus INSERT, UPDATE, DELETE, TRUNCATE, and COPY FROM.
    PREPARE and EXPLAIN ANALYZE statements are also logged if their contained command is of an appropriate type.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_statement
    Default value is ddl
    """
    gp_autostats_mode: global___GPAutostatsMode.ValueType
    """Specifies the mode for triggering automatic statistics collection after DML.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_autostats_mode
    """
    log_error_verbosity: global___LogErrorVerbosity.ValueType
    """Controls the amount of detail written in the server log for each message that is logged.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_error_verbosity
    """
    log_min_messages: global___LogLevelMessage.ValueType
    """Controls which message levels are written to the server log.
    Each level includes all the levels that follow it. The later the level, the fewer messages are sent to the log.
    https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_min_messages
    """
    @property
    def max_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of concurrent connections to the database server.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#max_connections
        """

    @property
    def max_slot_wal_keep_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum size in megabytes of Write-Ahead Logging (WAL) files on disk per segment instance that can be reserved
        when Greenplum streams data to the mirror segment instance or standby coordinator to keep it synchronized
        with the corresponding primary segment instance or coordinator.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#max_slot_wal_keep_size
        """

    @property
    def gp_workfile_limit_per_segment(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum total disk size that all running queries are allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_per_segment
        """

    @property
    def gp_workfile_limit_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum disk size an individual query is allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_per_query
        """

    @property
    def gp_workfile_limit_files_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of temporary spill files (also known as workfiles) allowed per query per segment.
        Spill files are created when executing a query that requires more memory than it is allocated.
        The current query is terminated when the limit is exceeded.
        Set the value to 0 (zero) to allow an unlimited number of spill files. master session reload
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_files_per_query
        Default value is 10000
        """

    @property
    def max_prepared_transactions(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of transactions that can be in the "prepared" state simultaneously
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#max_prepared_transactions
        """

    @property
    def gp_workfile_compression(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Specifies whether the temporary files created, when a hash aggregation or hash join operation spills to disk, are compressed.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_compression
        """

    @property
    def max_statement_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum memory limit for a query. Helps avoid out-of-memory errors on a segment host during query processing as a result of setting statement_mem too high.
        Taking into account the configuration of a single segment host, calculate max_statement_mem as follows:
        (seghost_physical_memory) / (average_number_concurrent_queries)
        When changing both max_statement_mem and statement_mem, max_statement_mem must be changed first, or listed first in the postgresql.conf file.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#max_statement_mem
        Default value is 2097152000 (2000MB)
        in bytes
        """

    @property
    def gp_enable_global_deadlock_detector(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Controls whether the Greenplum Database Global Deadlock Detector is enabled to manage concurrent UPDATE and DELETE operations on heap tables to improve performance. See Inserting, Updating, and Deleting Datain the Greenplum Database Administrator Guide. The default is off, the Global Deadlock Detector is deactivated.
        If the Global Deadlock Detector is deactivated (the default), Greenplum Database runs concurrent update and delete operations on a heap table serially.
        If the Global Deadlock Detector is enabled, concurrent updates are permitted and the Global Deadlock Detector determines when a deadlock exists, and breaks the deadlock by cancelling one or more backend processes associated with the youngest transaction(s) involved.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#gp_enable_global_deadlock_detector
        """

    @property
    def gp_global_deadlock_detector_period(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the executing interval (in seconds) of the global deadlock detector background worker process.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_global_deadlock_detector_period
        """

    @property
    def gp_max_slices(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max amount of slice-processes for one query in one segment.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_max_slices
        """

    @property
    def gp_cached_segworkers_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Define amount of working processes in segment, that keeping in warm cash after end of query for usage again in next queries.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_cached_segworkers_threshold
        """

    @property
    def lock_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max time (in ms) which query will wait lock free on object
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#lock_timeout
        """

    @property
    def idle_in_transaction_session_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max time (in ms) which session can idle in open transaction
        https://postgrespro.ru/docs/postgrespro/current/runtime-config-client#GUC-IDLE-IN-TRANSACTION-SESSION-TIMEOUT
        """

    @property
    def runaway_detector_activation_percent(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Percent of utilized Greenplum Database vmem that triggers the termination of queries.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#runaway_detector_activation_percent
        """

    @property
    def gp_vmem_protect_segworker_cache_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Set memory limit (in MB) for working process. If a query executor process consumes more than this configured amount, then the process will not be cached for use in subsequent queries after the process completes.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_vmem_protect_segworker_cache_limit
        """

    @property
    def gp_enable_zstd_memory_accounting(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Forces ZSTD lib use Greenplum memory allocation system."""

    @property
    def gp_max_plan_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the total maximum uncompressed size of a query execution plan multiplied by the number of Motion operators (slices) in the plan.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_max_plan_size
        """

    @property
    def gp_autostats_on_change_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specifies the threshold for automatic statistics collection when gp_autostats_mode is set to on_change.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_autostats_on_change_threshold
        """

    @property
    def gp_resource_group_memory_limit(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """Identifies the maximum percentage of system memory resources to allocate to resource groups on each Greenplum Database segment node.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_resource_group_memory_limit
        """

    @property
    def log_connections(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """This outputs a line to the server log detailing each successful connection. Some client programs, like psql,
        attempt to connect twice while determining if a password is required, so duplicate "connection received" messages
        do not always indicate a problem.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_connections
        """

    @property
    def log_disconnections(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """This outputs a line in the server log at termination of a client session, and includes the duration of the session.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_disconnections
        """

    @property
    def log_hostname(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """By default, connection log messages only show the IP address of the connecting host.
        Turning on this option causes logging of the host name as well. Note that depending on your host name
        resolution setup this might impose a non-negligible performance penalty.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_hostname
        """

    @property
    def log_statement_stats(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """For each query, write total performance statistics of the query parser, planner, and executor to the server log.
        This is a crude profiling instrument.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_statement_stats
        """

    @property
    def log_min_duration_statement(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Logs the statement and its duration on a single log line if its duration is greater than or equal
        to the specified number of milliseconds. Setting this to 0 will print all statements and their durations.
        -1 deactivates the feature. For example, if you set it to 250 then all SQL statements that run 250ms or longer will be logged.
        Enabling this option can be useful in tracking down unoptimized queries in your applications.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#log_statement_stats
        in milliseconds.
        """

    @property
    def master_shared_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the amount of memory a Greenplum Database master instance uses for shared memory buffers.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#shared_buffers
        """

    @property
    def max_locks_per_transaction(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The shared lock table is created with room to describe locks on max_locks_per_transaction * (max_connections + max_prepared_transactions) objects,
        so no more than this many distinct objects can be locked at any one time.
        This is not a hard limit on the number of locks taken by any one transaction, but rather a maximum average value.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#max_locks_per_transaction
        """

    @property
    def segment_shared_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the amount of memory a Greenplum Database segment instance uses for shared memory buffers.
        https://techdocs.broadcom.com/us/en/vmware-tanzu/data-solutions/tanzu-greenplum/7/greenplum-database/ref_guide-config_params-guc-list.html#shared_buffers
        """

    def __init__(
        self,
        *,
        max_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_slot_wal_keep_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_segment: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_files_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_prepared_transactions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_compression: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_statement_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_statement: global___LogStatement.ValueType = ...,
        gp_enable_global_deadlock_detector: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        gp_global_deadlock_detector_period: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_max_slices: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_cached_segworkers_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        lock_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        idle_in_transaction_session_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        runaway_detector_activation_percent: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_vmem_protect_segworker_cache_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_enable_zstd_memory_accounting: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        gp_max_plan_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_autostats_mode: global___GPAutostatsMode.ValueType = ...,
        gp_autostats_on_change_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_resource_group_memory_limit: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        log_connections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_disconnections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_hostname: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_statement_stats: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_min_duration_statement: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        master_shared_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_locks_per_transaction: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        segment_shared_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_error_verbosity: global___LogErrorVerbosity.ValueType = ...,
        log_min_messages: global___LogLevelMessage.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["gp_autostats_on_change_threshold", b"gp_autostats_on_change_threshold", "gp_cached_segworkers_threshold", b"gp_cached_segworkers_threshold", "gp_enable_global_deadlock_detector", b"gp_enable_global_deadlock_detector", "gp_enable_zstd_memory_accounting", b"gp_enable_zstd_memory_accounting", "gp_global_deadlock_detector_period", b"gp_global_deadlock_detector_period", "gp_max_plan_size", b"gp_max_plan_size", "gp_max_slices", b"gp_max_slices", "gp_resource_group_memory_limit", b"gp_resource_group_memory_limit", "gp_vmem_protect_segworker_cache_limit", b"gp_vmem_protect_segworker_cache_limit", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "lock_timeout", b"lock_timeout", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_hostname", b"log_hostname", "log_min_duration_statement", b"log_min_duration_statement", "log_statement_stats", b"log_statement_stats", "master_shared_buffers", b"master_shared_buffers", "max_connections", b"max_connections", "max_locks_per_transaction", b"max_locks_per_transaction", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem", "runaway_detector_activation_percent", b"runaway_detector_activation_percent", "segment_shared_buffers", b"segment_shared_buffers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["gp_autostats_mode", b"gp_autostats_mode", "gp_autostats_on_change_threshold", b"gp_autostats_on_change_threshold", "gp_cached_segworkers_threshold", b"gp_cached_segworkers_threshold", "gp_enable_global_deadlock_detector", b"gp_enable_global_deadlock_detector", "gp_enable_zstd_memory_accounting", b"gp_enable_zstd_memory_accounting", "gp_global_deadlock_detector_period", b"gp_global_deadlock_detector_period", "gp_max_plan_size", b"gp_max_plan_size", "gp_max_slices", b"gp_max_slices", "gp_resource_group_memory_limit", b"gp_resource_group_memory_limit", "gp_vmem_protect_segworker_cache_limit", b"gp_vmem_protect_segworker_cache_limit", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "lock_timeout", b"lock_timeout", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_error_verbosity", b"log_error_verbosity", "log_hostname", b"log_hostname", "log_min_duration_statement", b"log_min_duration_statement", "log_min_messages", b"log_min_messages", "log_statement", b"log_statement", "log_statement_stats", b"log_statement_stats", "master_shared_buffers", b"master_shared_buffers", "max_connections", b"max_connections", "max_locks_per_transaction", b"max_locks_per_transaction", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem", "runaway_detector_activation_percent", b"runaway_detector_activation_percent", "segment_shared_buffers", b"segment_shared_buffers"]) -> None: ...

global___GreenplumConfigCBDB = GreenplumConfigCBDB

@typing.final
class GreenplumConfigSet6(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___GreenplumConfig6:
        """Effective settings for a Greenplum (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___GreenplumConfig6:
        """User-defined settings for a Greenplum."""

    @property
    def default_config(self) -> global___GreenplumConfig6:
        """Default configuration for a Greenplum."""

    def __init__(
        self,
        *,
        effective_config: global___GreenplumConfig6 | None = ...,
        user_config: global___GreenplumConfig6 | None = ...,
        default_config: global___GreenplumConfig6 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___GreenplumConfigSet6 = GreenplumConfigSet6

@typing.final
class ConnectionPoolerConfigSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___ConnectionPoolerConfig:
        """Effective settings for an Odyssey® pooler (a combination of settings defined in [ConnectionPoolerConfigSet.user_config] and [ConnectionPoolerConfigSet.default_config])."""

    @property
    def user_config(self) -> global___ConnectionPoolerConfig:
        """User-defined settings for an Odyssey® pooler."""

    @property
    def default_config(self) -> global___ConnectionPoolerConfig:
        """Default configuration for an Odyssey® pooler."""

    def __init__(
        self,
        *,
        effective_config: global___ConnectionPoolerConfig | None = ...,
        user_config: global___ConnectionPoolerConfig | None = ...,
        default_config: global___ConnectionPoolerConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___ConnectionPoolerConfigSet = ConnectionPoolerConfigSet

@typing.final
class GreenplumConfigSetCBDB(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___GreenplumConfigCBDB:
        """Effective settings for a Cloudberry (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___GreenplumConfigCBDB:
        """User-defined settings for a Cloudberry."""

    @property
    def default_config(self) -> global___GreenplumConfigCBDB:
        """Default configuration for a Cloudberry."""

    def __init__(
        self,
        *,
        effective_config: global___GreenplumConfigCBDB | None = ...,
        user_config: global___GreenplumConfigCBDB | None = ...,
        default_config: global___GreenplumConfigCBDB | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___GreenplumConfigSetCBDB = GreenplumConfigSetCBDB



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/synchronization_session_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/synchronization_session_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.idp import synchronization_settings_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_synchronization__settings__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMyandex/cloud/organizationmanager/v1/idp/synchronization_session_service.proto\x12\'yandex.cloud.organizationmanager.v1.idp\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x46yandex/cloud/organizationmanager/v1/idp/synchronization_settings.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb2\x01\n\x12OpenSessionRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x08\x61gent_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12P\n\x0csession_type\x18\x03 \x01(\x0e\x32\x34.yandex.cloud.organizationmanager.v1.idp.SessionTypeB\x04\xe8\xc7\x31\x01\"\x8e\x04\n\x16SynchronizationSession\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tclosed_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\tsync_mode\x18\x06 \x01(\x0e\x32\x31.yandex.cloud.organizationmanager.v1.idp.SyncMode\x12\x46\n\x06status\x18\x07 \x01(\x0e\x32\x36.yandex.cloud.organizationmanager.v1.idp.SessionStatus\x12P\n\x10progress_entries\x18\x08 \x03(\x0b\x32\x36.yandex.cloud.organizationmanager.v1.idp.ProgressEntry\x12\x13\n\x0b\x66\x61il_reason\x18\t \x01(\t\x12J\n\x0csession_type\x18\n \x01(\x0e\x32\x34.yandex.cloud.organizationmanager.v1.idp.SessionType\"\x82\x03\n\x13OpenSessionResponse\x12J\n\x06result\x18\x01 \x01(\x0e\x32:.yandex.cloud.organizationmanager.v1.idp.OpenSessionResult\x12Y\n\x0eopened_session\x18\x02 \x01(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.SynchronizationSessionH\x00\x12\x35\n\x0fnext_session_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x19\n\x11replication_token\x18\x04 \x01(\t\x12\x62\n\x18synchronization_settings\x18\x05 \x01(\x0b\x32@.yandex.cloud.organizationmanager.v1.idp.SynchronizationSettingsB\x0e\n\x0csession_info\")\n\x13OpenSessionMetadata\x12\x12\n\nsession_id\x18\x01 \x01(\t\"5\n\x11GetSessionRequest\x12 \n\nsession_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"f\n\x12GetSessionResponse\x12P\n\x07session\x18\x01 \x01(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.SynchronizationSession\"\x9b\x01\n\x1cReportSessionProgressRequest\x12 \n\nsession_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12Y\n\x10progress_entries\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.organizationmanager.v1.idp.ProgressEntryB\x07\x82\xc8\x31\x03\x31-3\"3\n\x1dReportSessionProgressMetadata\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\xb9\x01\n\rProgressEntry\x12U\n\x0bobject_type\x18\x01 \x01(\x0e\x32:.yandex.cloud.organizationmanager.v1.idp.RelatedObjectTypeB\x04\xe8\xc7\x31\x01\x12Q\n\x0b\x63hange_info\x18\x02 \x03(\x0b\x32\x33.yandex.cloud.organizationmanager.v1.idp.ChangeInfoB\x07\x82\xc8\x31\x03\x31-6\"z\n\nChangeInfo\x12H\n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x33.yandex.cloud.organizationmanager.v1.idp.ChangeType\x12\x12\n\nsuccessful\x18\x02 \x01(\x03\x12\x0e\n\x06\x66\x61iled\x18\x03 \x01(\x03\"\x9c\x01\n\x13ListSessionsRequest\x12*\n\x14subject_container_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x82\x01\n\x14ListSessionsResponse\x12Q\n\x08sessions\x18\x01 \x03(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.SynchronizationSession\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"g\n\x13\x43loseSessionRequest\x12 \n\nsession_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0e\n\x06\x66\x61iled\x18\x02 \x01(\x08\x12\x1e\n\x0b\x66\x61il_reason\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\"*\n\x14\x43loseSessionMetadata\x12\x12\n\nsession_id\x18\x01 \x01(\t\"4\n\x10HeartbeatRequest\x12 \n\nsession_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\'\n\x11HeartbeatMetadata\x12\x12\n\nsession_id\x18\x01 \x01(\t*o\n\x11OpenSessionResult\x12#\n\x1fOPEN_SESSION_RESULT_UNSPECIFIED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x19\n\x15OPENED_SESSION_EXISTS\x10\x02\x12\r\n\tTOO_EARLY\x10\x03*\x85\x01\n\nChangeType\x12\x1b\n\x17\x43HANGE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\x0c\n\x08\x41\x43TIVATE\x10\x04\x12\x0e\n\nDEACTIVATE\x10\x05\x12\x18\n\x14PASSWORD_HASH_UPDATE\x10\x06*]\n\x11RelatedObjectType\x12#\n\x1fRELATED_OBJECT_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04USER\x10\x01\x12\t\n\x05GROUP\x10\x02\x12\x0e\n\nMEMBERSHIP\x10\x03*?\n\x08SyncMode\x12\x19\n\x15SYNC_MODE_UNSPECIFIED\x10\x00\x12\r\n\tFULL_SYNC\x10\x01\x12\t\n\x05\x44\x45LTA\x10\x02*p\n\rSessionStatus\x12\x1e\n\x1aSESSION_STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06OPENED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0b\n\x07\x45XPIRED\x10\x05\x32\xb1\x0b\n\x1dSynchronizationSessionService\x12\xe2\x01\n\x0bOpenSession\x12;.yandex.cloud.organizationmanager.v1.idp.OpenSessionRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2**\n\x13OpenSessionMetadata\x12\x13OpenSessionResponse\x82\xd3\xe4\x93\x02?\":/organization-manager/v1/idp/synchronization-sessions:open:\x01*\x12\xf7\x01\n\x0c\x43loseSession\x12<.yandex.cloud.organizationmanager.v1.idp.CloseSessionRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*.\n\x14\x43loseSessionMetadata\x12\x16SynchronizationSession\x82\xd3\xe4\x93\x02M\"H/organization-manager/v1/idp/synchronization-sessions/{session_id}:close:\x01*\x12\x9b\x02\n\x15ReportSessionProgress\x12\x45.yandex.cloud.organizationmanager.v1.idp.ReportSessionProgressRequest\x1a!.yandex.cloud.operation.Operation\"\x97\x01\xb2\xd2*7\n\x1dReportSessionProgressMetadata\x12\x16SynchronizationSession\x82\xd3\xe4\x93\x02V\"Q/organization-manager/v1/idp/synchronization-sessions/{session_id}:reportProgress:\x01*\x12\xf1\x01\n\tHeartbeat\x12\x39.yandex.cloud.organizationmanager.v1.idp.HeartbeatRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2**\n\x11HeartbeatMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02Q\"L/organization-manager/v1/idp/synchronization-sessions/{session_id}:heartbeat:\x01*\x12\xd1\x01\n\nGetSession\x12:.yandex.cloud.organizationmanager.v1.idp.GetSessionRequest\x1a;.yandex.cloud.organizationmanager.v1.idp.GetSessionResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/organization-manager/v1/idp/synchronization-sessions/{session_id}\x12\xca\x01\n\x0cListSessions\x12<.yandex.cloud.organizationmanager.v1.idp.ListSessionsRequest\x1a=.yandex.cloud.organizationmanager.v1.idp.ListSessionsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/organization-manager/v1/idp/synchronization-sessionsB~\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.synchronization_session_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idp'
  _globals['_OPENSESSIONREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_OPENSESSIONREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_OPENSESSIONREQUEST'].fields_by_name['agent_id']._loaded_options = None
  _globals['_OPENSESSIONREQUEST'].fields_by_name['agent_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_OPENSESSIONREQUEST'].fields_by_name['session_type']._loaded_options = None
  _globals['_OPENSESSIONREQUEST'].fields_by_name['session_type']._serialized_options = b'\350\3071\001'
  _globals['_GETSESSIONREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_GETSESSIONREQUEST'].fields_by_name['session_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REPORTSESSIONPROGRESSREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_REPORTSESSIONPROGRESSREQUEST'].fields_by_name['session_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REPORTSESSIONPROGRESSREQUEST'].fields_by_name['progress_entries']._loaded_options = None
  _globals['_REPORTSESSIONPROGRESSREQUEST'].fields_by_name['progress_entries']._serialized_options = b'\202\3101\0031-3'
  _globals['_PROGRESSENTRY'].fields_by_name['object_type']._loaded_options = None
  _globals['_PROGRESSENTRY'].fields_by_name['object_type']._serialized_options = b'\350\3071\001'
  _globals['_PROGRESSENTRY'].fields_by_name['change_info']._loaded_options = None
  _globals['_PROGRESSENTRY'].fields_by_name['change_info']._serialized_options = b'\202\3101\0031-6'
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['subject_container_id']._loaded_options = None
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['subject_container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSESSIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CLOSESESSIONREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_CLOSESESSIONREQUEST'].fields_by_name['session_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CLOSESESSIONREQUEST'].fields_by_name['fail_reason']._loaded_options = None
  _globals['_CLOSESESSIONREQUEST'].fields_by_name['fail_reason']._serialized_options = b'\212\3101\005<=256'
  _globals['_HEARTBEATREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_HEARTBEATREQUEST'].fields_by_name['session_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['OpenSession']._loaded_options = None
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['OpenSession']._serialized_options = b'\262\322**\n\023OpenSessionMetadata\022\023OpenSessionResponse\202\323\344\223\002?\":/organization-manager/v1/idp/synchronization-sessions:open:\001*'
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['CloseSession']._loaded_options = None
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['CloseSession']._serialized_options = b'\262\322*.\n\024CloseSessionMetadata\022\026SynchronizationSession\202\323\344\223\002M\"H/organization-manager/v1/idp/synchronization-sessions/{session_id}:close:\001*'
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['ReportSessionProgress']._loaded_options = None
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['ReportSessionProgress']._serialized_options = b'\262\322*7\n\035ReportSessionProgressMetadata\022\026SynchronizationSession\202\323\344\223\002V\"Q/organization-manager/v1/idp/synchronization-sessions/{session_id}:reportProgress:\001*'
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['Heartbeat']._loaded_options = None
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['Heartbeat']._serialized_options = b'\262\322**\n\021HeartbeatMetadata\022\025google.protobuf.Empty\202\323\344\223\002Q\"L/organization-manager/v1/idp/synchronization-sessions/{session_id}:heartbeat:\001*'
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['GetSession']._loaded_options = None
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['GetSession']._serialized_options = b'\202\323\344\223\002D\022B/organization-manager/v1/idp/synchronization-sessions/{session_id}'
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['ListSessions']._loaded_options = None
  _globals['_SYNCHRONIZATIONSESSIONSERVICE'].methods_by_name['ListSessions']._serialized_options = b'\202\323\344\223\0027\0225/organization-manager/v1/idp/synchronization-sessions'
  _globals['_OPENSESSIONRESULT']._serialized_start=2722
  _globals['_OPENSESSIONRESULT']._serialized_end=2833
  _globals['_CHANGETYPE']._serialized_start=2836
  _globals['_CHANGETYPE']._serialized_end=2969
  _globals['_RELATEDOBJECTTYPE']._serialized_start=2971
  _globals['_RELATEDOBJECTTYPE']._serialized_end=3064
  _globals['_SYNCMODE']._serialized_start=3066
  _globals['_SYNCMODE']._serialized_end=3129
  _globals['_SESSIONSTATUS']._serialized_start=3131
  _globals['_SESSIONSTATUS']._serialized_end=3243
  _globals['_OPENSESSIONREQUEST']._serialized_start=363
  _globals['_OPENSESSIONREQUEST']._serialized_end=541
  _globals['_SYNCHRONIZATIONSESSION']._serialized_start=544
  _globals['_SYNCHRONIZATIONSESSION']._serialized_end=1070
  _globals['_OPENSESSIONRESPONSE']._serialized_start=1073
  _globals['_OPENSESSIONRESPONSE']._serialized_end=1459
  _globals['_OPENSESSIONMETADATA']._serialized_start=1461
  _globals['_OPENSESSIONMETADATA']._serialized_end=1502
  _globals['_GETSESSIONREQUEST']._serialized_start=1504
  _globals['_GETSESSIONREQUEST']._serialized_end=1557
  _globals['_GETSESSIONRESPONSE']._serialized_start=1559
  _globals['_GETSESSIONRESPONSE']._serialized_end=1661
  _globals['_REPORTSESSIONPROGRESSREQUEST']._serialized_start=1664
  _globals['_REPORTSESSIONPROGRESSREQUEST']._serialized_end=1819
  _globals['_REPORTSESSIONPROGRESSMETADATA']._serialized_start=1821
  _globals['_REPORTSESSIONPROGRESSMETADATA']._serialized_end=1872
  _globals['_PROGRESSENTRY']._serialized_start=1875
  _globals['_PROGRESSENTRY']._serialized_end=2060
  _globals['_CHANGEINFO']._serialized_start=2062
  _globals['_CHANGEINFO']._serialized_end=2184
  _globals['_LISTSESSIONSREQUEST']._serialized_start=2187
  _globals['_LISTSESSIONSREQUEST']._serialized_end=2343
  _globals['_LISTSESSIONSRESPONSE']._serialized_start=2346
  _globals['_LISTSESSIONSRESPONSE']._serialized_end=2476
  _globals['_CLOSESESSIONREQUEST']._serialized_start=2478
  _globals['_CLOSESESSIONREQUEST']._serialized_end=2581
  _globals['_CLOSESESSIONMETADATA']._serialized_start=2583
  _globals['_CLOSESESSIONMETADATA']._serialized_end=2625
  _globals['_HEARTBEATREQUEST']._serialized_start=2627
  _globals['_HEARTBEATREQUEST']._serialized_end=2679
  _globals['_HEARTBEATMETADATA']._serialized_start=2681
  _globals['_HEARTBEATMETADATA']._serialized_end=2720
  _globals['_SYNCHRONIZATIONSESSIONSERVICE']._serialized_start=3246
  _globals['_SYNCHRONIZATIONSESSIONSERVICE']._serialized_end=4703
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ResourceManagementConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_GROUPS_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    @property
    def resource_groups(self) -> global___ResourceGroupsConfig:
        """Resource groups configuration."""

    @property
    def query(self) -> global___QueryConfig:
        """Query management confiugration."""

    def __init__(
        self,
        *,
        resource_groups: global___ResourceGroupsConfig | None = ...,
        query: global___QueryConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["query", b"query", "resource_groups", b"resource_groups"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["query", b"query", "resource_groups", b"resource_groups"]) -> None: ...

global___ResourceManagementConfig = ResourceManagementConfig

@typing.final
class QueryConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Query properties."""

    def __init__(
        self,
        *,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["properties", b"properties"]) -> None: ...

global___QueryConfig = QueryConfig

@typing.final
class ResourceGroupsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOT_GROUPS_FIELD_NUMBER: builtins.int
    SELECTORS_FIELD_NUMBER: builtins.int
    CPU_QUOTA_PERIOD_FIELD_NUMBER: builtins.int
    cpu_quota_period: builtins.str
    """Period for CPU quota calculations."""
    @property
    def root_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceGroupConfig]:
        """Root resource groups configuration."""

    @property
    def selectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SelectorRuleConfig]:
        """Selector rules for routing queries to resource groups."""

    def __init__(
        self,
        *,
        root_groups: collections.abc.Iterable[global___ResourceGroupConfig] | None = ...,
        selectors: collections.abc.Iterable[global___SelectorRuleConfig] | None = ...,
        cpu_quota_period: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cpu_quota_period", b"cpu_quota_period", "root_groups", b"root_groups", "selectors", b"selectors"]) -> None: ...

global___ResourceGroupsConfig = ResourceGroupsConfig

@typing.final
class ResourceGroupConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _SchedulingPolicy:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SchedulingPolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ResourceGroupConfig._SchedulingPolicy.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SCHEDULING_POLICY_UNSPECIFIED: ResourceGroupConfig._SchedulingPolicy.ValueType  # 0
        FAIR: ResourceGroupConfig._SchedulingPolicy.ValueType  # 1
        """Queued queries processed first-in-first-out, sub-groups take turns starting queries."""
        WEIGHTED: ResourceGroupConfig._SchedulingPolicy.ValueType  # 2
        """Queries selected stochastically by priority, sub-groups selected by schedulingWeight."""
        WEIGHTED_FAIR: ResourceGroupConfig._SchedulingPolicy.ValueType  # 3
        """Sub-groups selected by schedulingWeight and concurrency relative to their share."""
        QUERY_PRIORITY: ResourceGroupConfig._SchedulingPolicy.ValueType  # 4
        """Queued queries selected strictly by priority."""

    class SchedulingPolicy(_SchedulingPolicy, metaclass=_SchedulingPolicyEnumTypeWrapper): ...
    SCHEDULING_POLICY_UNSPECIFIED: ResourceGroupConfig.SchedulingPolicy.ValueType  # 0
    FAIR: ResourceGroupConfig.SchedulingPolicy.ValueType  # 1
    """Queued queries processed first-in-first-out, sub-groups take turns starting queries."""
    WEIGHTED: ResourceGroupConfig.SchedulingPolicy.ValueType  # 2
    """Queries selected stochastically by priority, sub-groups selected by schedulingWeight."""
    WEIGHTED_FAIR: ResourceGroupConfig.SchedulingPolicy.ValueType  # 3
    """Sub-groups selected by schedulingWeight and concurrency relative to their share."""
    QUERY_PRIORITY: ResourceGroupConfig.SchedulingPolicy.ValueType  # 4
    """Queued queries selected strictly by priority."""

    NAME_FIELD_NUMBER: builtins.int
    MAX_QUEUED_FIELD_NUMBER: builtins.int
    SOFT_CONCURRENCY_LIMIT_FIELD_NUMBER: builtins.int
    HARD_CONCURRENCY_LIMIT_FIELD_NUMBER: builtins.int
    SOFT_MEMORY_LIMIT_FIELD_NUMBER: builtins.int
    SOFT_CPU_LIMIT_FIELD_NUMBER: builtins.int
    HARD_CPU_LIMIT_FIELD_NUMBER: builtins.int
    SCHEDULING_POLICY_FIELD_NUMBER: builtins.int
    SCHEDULING_WEIGHT_FIELD_NUMBER: builtins.int
    SUB_GROUPS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Resource group name."""
    max_queued: builtins.int
    """Maximum number of queued queries."""
    soft_concurrency_limit: builtins.int
    """Number of concurrently running queries after which new queries only run if peer groups are below soft limits."""
    hard_concurrency_limit: builtins.int
    """Maximum number of queries that can run concurrently."""
    soft_memory_limit: builtins.str
    """Maximum amount of distributed memory this group can use."""
    soft_cpu_limit: builtins.str
    """Maximum CPU time per period this group can use before applying penalty to running queries (requires hard_cpu_limit)."""
    hard_cpu_limit: builtins.str
    """Maximum CPU time per period this group can use."""
    scheduling_policy: global___ResourceGroupConfig.SchedulingPolicy.ValueType
    """Policy for selecting queued queries and sub-group eligibility."""
    scheduling_weight: builtins.int
    """Weight for weighted and weighted_fair scheduling policies."""
    @property
    def sub_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceGroupConfig]:
        """List of sub-groups."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        max_queued: builtins.int = ...,
        soft_concurrency_limit: builtins.int = ...,
        hard_concurrency_limit: builtins.int = ...,
        soft_memory_limit: builtins.str = ...,
        soft_cpu_limit: builtins.str = ...,
        hard_cpu_limit: builtins.str = ...,
        scheduling_policy: global___ResourceGroupConfig.SchedulingPolicy.ValueType = ...,
        scheduling_weight: builtins.int = ...,
        sub_groups: collections.abc.Iterable[global___ResourceGroupConfig] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hard_concurrency_limit", b"hard_concurrency_limit", "hard_cpu_limit", b"hard_cpu_limit", "max_queued", b"max_queued", "name", b"name", "scheduling_policy", b"scheduling_policy", "scheduling_weight", b"scheduling_weight", "soft_concurrency_limit", b"soft_concurrency_limit", "soft_cpu_limit", b"soft_cpu_limit", "soft_memory_limit", b"soft_memory_limit", "sub_groups", b"sub_groups"]) -> None: ...

global___ResourceGroupConfig = ResourceGroupConfig

@typing.final
class SelectorRuleConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _QueryType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _QueryTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SelectorRuleConfig._QueryType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        QUERY_TYPE_UNSPECIFIED: SelectorRuleConfig._QueryType.ValueType  # 0
        SELECT: SelectorRuleConfig._QueryType.ValueType  # 1
        EXPLAIN: SelectorRuleConfig._QueryType.ValueType  # 2
        DESCRIBE: SelectorRuleConfig._QueryType.ValueType  # 3
        INSERT: SelectorRuleConfig._QueryType.ValueType  # 4
        UPDATE: SelectorRuleConfig._QueryType.ValueType  # 5
        MERGE: SelectorRuleConfig._QueryType.ValueType  # 6
        DELETE: SelectorRuleConfig._QueryType.ValueType  # 7
        ANALYZE: SelectorRuleConfig._QueryType.ValueType  # 8
        DATA_DEFINITION: SelectorRuleConfig._QueryType.ValueType  # 9
        ALTER_TABLE_EXECUTE: SelectorRuleConfig._QueryType.ValueType  # 10

    class QueryType(_QueryType, metaclass=_QueryTypeEnumTypeWrapper): ...
    QUERY_TYPE_UNSPECIFIED: SelectorRuleConfig.QueryType.ValueType  # 0
    SELECT: SelectorRuleConfig.QueryType.ValueType  # 1
    EXPLAIN: SelectorRuleConfig.QueryType.ValueType  # 2
    DESCRIBE: SelectorRuleConfig.QueryType.ValueType  # 3
    INSERT: SelectorRuleConfig.QueryType.ValueType  # 4
    UPDATE: SelectorRuleConfig.QueryType.ValueType  # 5
    MERGE: SelectorRuleConfig.QueryType.ValueType  # 6
    DELETE: SelectorRuleConfig.QueryType.ValueType  # 7
    ANALYZE: SelectorRuleConfig.QueryType.ValueType  # 8
    DATA_DEFINITION: SelectorRuleConfig.QueryType.ValueType  # 9
    ALTER_TABLE_EXECUTE: SelectorRuleConfig.QueryType.ValueType  # 10

    USER_FIELD_NUMBER: builtins.int
    USER_GROUP_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    QUERY_TYPE_FIELD_NUMBER: builtins.int
    CLIENT_TAGS_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    user: builtins.str
    """Regex to match against username."""
    user_group: builtins.str
    """Regex to match against user groups."""
    source: builtins.str
    """Regex to match against query source."""
    query_type: global___SelectorRuleConfig.QueryType.ValueType
    """Type of query to match."""
    group: builtins.str
    """Target resource group name."""
    @property
    def client_tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Tags that must all be present in the query's client tags."""

    def __init__(
        self,
        *,
        user: builtins.str = ...,
        user_group: builtins.str = ...,
        source: builtins.str = ...,
        query_type: global___SelectorRuleConfig.QueryType.ValueType = ...,
        client_tags: collections.abc.Iterable[builtins.str] | None = ...,
        group: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["client_tags", b"client_tags", "group", b"group", "query_type", b"query_type", "source", b"source", "user", b"user", "user_group", b"user_group"]) -> None: ...

global___SelectorRuleConfig = SelectorRuleConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.searchapi.v2.wordstat_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class WordstatServiceStub:
    """A set of methods for viewing statistics on search queries to Yandex."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetTop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetTopRequest,
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetTopResponse,
    ]
    """The method returns the last 30 days data about popular queries containing the specified keyword and queries that are similar to the specified one."""

    GetDynamics: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetDynamicsRequest,
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetDynamicsResponse,
    ]
    """The method returns the frequency of queries over time for a given keyword."""

    GetRegionsDistribution: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsDistributionRequest,
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsDistributionResponse,
    ]
    """The method returns the distribution of the number of queries containing the given keyword globally by region for the last 30 days."""

    GetRegionsTree: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsTreeRequest,
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsTreeResponse,
    ]
    """The method method returns a tree of Wordstat-supported regions."""

class WordstatServiceAsyncStub:
    """A set of methods for viewing statistics on search queries to Yandex."""

    GetTop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetTopRequest,
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetTopResponse,
    ]
    """The method returns the last 30 days data about popular queries containing the specified keyword and queries that are similar to the specified one."""

    GetDynamics: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetDynamicsRequest,
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetDynamicsResponse,
    ]
    """The method returns the frequency of queries over time for a given keyword."""

    GetRegionsDistribution: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsDistributionRequest,
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsDistributionResponse,
    ]
    """The method returns the distribution of the number of queries containing the given keyword globally by region for the last 30 days."""

    GetRegionsTree: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsTreeRequest,
        yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsTreeResponse,
    ]
    """The method method returns a tree of Wordstat-supported regions."""

class WordstatServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for viewing statistics on search queries to Yandex."""

    @abc.abstractmethod
    def GetTop(
        self,
        request: yandex.cloud.searchapi.v2.wordstat_service_pb2.GetTopRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.searchapi.v2.wordstat_service_pb2.GetTopResponse, collections.abc.Awaitable[yandex.cloud.searchapi.v2.wordstat_service_pb2.GetTopResponse]]:
        """The method returns the last 30 days data about popular queries containing the specified keyword and queries that are similar to the specified one."""

    @abc.abstractmethod
    def GetDynamics(
        self,
        request: yandex.cloud.searchapi.v2.wordstat_service_pb2.GetDynamicsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.searchapi.v2.wordstat_service_pb2.GetDynamicsResponse, collections.abc.Awaitable[yandex.cloud.searchapi.v2.wordstat_service_pb2.GetDynamicsResponse]]:
        """The method returns the frequency of queries over time for a given keyword."""

    @abc.abstractmethod
    def GetRegionsDistribution(
        self,
        request: yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsDistributionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsDistributionResponse, collections.abc.Awaitable[yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsDistributionResponse]]:
        """The method returns the distribution of the number of queries containing the given keyword globally by region for the last 30 days."""

    @abc.abstractmethod
    def GetRegionsTree(
        self,
        request: yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsTreeRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsTreeResponse, collections.abc.Awaitable[yandex.cloud.searchapi.v2.wordstat_service_pb2.GetRegionsTreeResponse]]:
        """The method method returns a tree of Wordstat-supported regions."""

def add_WordstatServiceServicer_to_server(servicer: WordstatServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.baremetal.v1alpha.disk_pb2
import yandex.cloud.baremetal.v1alpha.storage_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Server(google.protobuf.message.Message):
    """A Server resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Server._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Server._Status.ValueType  # 0
        """Unspecified server status."""
        PROVISIONING: Server._Status.ValueType  # 1
        """Server is waiting for to be allocated from the hardware pool."""
        STOPPING: Server._Status.ValueType  # 3
        """Server is being stopped."""
        STOPPED: Server._Status.ValueType  # 4
        """Server has been stopped."""
        STARTING: Server._Status.ValueType  # 5
        """Server is being started."""
        RESTARTING: Server._Status.ValueType  # 6
        """Server is being restarted."""
        ERROR: Server._Status.ValueType  # 7
        """Server encountered a problem and cannot operate."""
        DELETING: Server._Status.ValueType  # 8
        """Server is being deleted."""
        REINSTALLING: Server._Status.ValueType  # 9
        """Server operating system is being reinstalled."""
        UPDATING: Server._Status.ValueType  # 10
        """Server is being updated."""
        QUARANTINED: Server._Status.ValueType  # 12
        """Server has been quarantined"""
        RUNNING: Server._Status.ValueType  # 14
        """Server is running normaly"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Server status."""

    STATUS_UNSPECIFIED: Server.Status.ValueType  # 0
    """Unspecified server status."""
    PROVISIONING: Server.Status.ValueType  # 1
    """Server is waiting for to be allocated from the hardware pool."""
    STOPPING: Server.Status.ValueType  # 3
    """Server is being stopped."""
    STOPPED: Server.Status.ValueType  # 4
    """Server has been stopped."""
    STARTING: Server.Status.ValueType  # 5
    """Server is being started."""
    RESTARTING: Server.Status.ValueType  # 6
    """Server is being restarted."""
    ERROR: Server.Status.ValueType  # 7
    """Server encountered a problem and cannot operate."""
    DELETING: Server.Status.ValueType  # 8
    """Server is being deleted."""
    REINSTALLING: Server.Status.ValueType  # 9
    """Server operating system is being reinstalled."""
    UPDATING: Server.Status.ValueType  # 10
    """Server is being updated."""
    QUARANTINED: Server.Status.ValueType  # 12
    """Server has been quarantined"""
    RUNNING: Server.Status.ValueType  # 14
    """Server is running normaly"""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    HARDWARE_POOL_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    OS_SETTINGS_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACES_FIELD_NUMBER: builtins.int
    CONFIGURATION_ID_FIELD_NUMBER: builtins.int
    DISKS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the server."""
    cloud_id: builtins.str
    """ID of the cloud that the server belongs to."""
    folder_id: builtins.str
    """ID of the folder that the server belongs to."""
    name: builtins.str
    """Name of the server.
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the server."""
    zone_id: builtins.str
    """ID of the availability zone where the server is resides."""
    hardware_pool_id: builtins.str
    """ID of the hardware pool that the server belongs to."""
    status: global___Server.Status.ValueType
    """Status of the server."""
    configuration_id: builtins.str
    """ID of the configuration that was used to create the server."""
    @property
    def os_settings(self) -> global___OsSettings:
        """Operating system specific settings of the server. Optional, will be empty if the server is
        provisioned without an operating system.
        """

    @property
    def network_interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkInterface]:
        """Array of network interfaces that are attached to the instance."""

    @property
    def disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.disk_pb2.Disk]:
        """Array of disks that are attached to the server."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        zone_id: builtins.str = ...,
        hardware_pool_id: builtins.str = ...,
        status: global___Server.Status.ValueType = ...,
        os_settings: global___OsSettings | None = ...,
        network_interfaces: collections.abc.Iterable[global___NetworkInterface] | None = ...,
        configuration_id: builtins.str = ...,
        disks: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.disk_pb2.Disk] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "os_settings", b"os_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "configuration_id", b"configuration_id", "created_at", b"created_at", "description", b"description", "disks", b"disks", "folder_id", b"folder_id", "hardware_pool_id", b"hardware_pool_id", "id", b"id", "labels", b"labels", "name", b"name", "network_interfaces", b"network_interfaces", "os_settings", b"os_settings", "status", b"status", "zone_id", b"zone_id"]) -> None: ...

global___Server = Server

@typing.final
class NetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    MAC_ADDRESS_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    PRIVATE_SUBNET_FIELD_NUMBER: builtins.int
    PUBLIC_SUBNET_FIELD_NUMBER: builtins.int
    PRIVATE_INTERFACE_FIELD_NUMBER: builtins.int
    PUBLIC_INTERFACE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the network interface."""
    mac_address: builtins.str
    """MAC address that is assigned to the network interface.

    Read only field.
    """
    ip_address: builtins.str
    """@deprecated. Use `interface.ipaddress` instead.
    IPv4 address that is assigned to the server for this network interface.

    Read only field.
    """
    @property
    def private_subnet(self) -> global___PrivateSubnetNetworkInterface:
        """@deprecated Private subnet."""

    @property
    def public_subnet(self) -> global___PublicSubnetNetworkInterface:
        """@deprecated Public subnet."""

    @property
    def private_interface(self) -> global___PrivateNetworkInterface:
        """Private interface."""

    @property
    def public_interface(self) -> global___PublicNetworkInterface:
        """Public interface."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        mac_address: builtins.str = ...,
        ip_address: builtins.str = ...,
        private_subnet: global___PrivateSubnetNetworkInterface | None = ...,
        public_subnet: global___PublicSubnetNetworkInterface | None = ...,
        private_interface: global___PrivateNetworkInterface | None = ...,
        public_interface: global___PublicNetworkInterface | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["interface", b"interface", "private_interface", b"private_interface", "private_subnet", b"private_subnet", "public_interface", b"public_interface", "public_subnet", b"public_subnet", "subnet", b"subnet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "interface", b"interface", "ip_address", b"ip_address", "mac_address", b"mac_address", "private_interface", b"private_interface", "private_subnet", b"private_subnet", "public_interface", b"public_interface", "public_subnet", b"public_subnet", "subnet", b"subnet"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["interface", b"interface"]) -> typing.Literal["private_interface", "public_interface"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["subnet", b"subnet"]) -> typing.Literal["private_subnet", "public_subnet"] | None: ...

global___NetworkInterface = NetworkInterface

@typing.final
class PrivateNetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NATIVE_SUBNET_ID_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    MAC_LIMIT_FIELD_NUMBER: builtins.int
    VLAN_SUBINTERFACES_FIELD_NUMBER: builtins.int
    native_subnet_id: builtins.str
    """ID of the private subnet which is used as native subnet for interface."""
    ip_address: builtins.str
    """IPv4 address that is assigned to the server for this network interface.

    Read only field.
    """
    mac_limit: builtins.int
    """Limit of MAC addresses in the native subnet.

    Read only field.
    """
    @property
    def vlan_subinterfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VLANSubinterface]:
        """Array of VLAN subinterfaces. Additional tagged subnets for the interface."""

    def __init__(
        self,
        *,
        native_subnet_id: builtins.str = ...,
        ip_address: builtins.str = ...,
        mac_limit: builtins.int = ...,
        vlan_subinterfaces: collections.abc.Iterable[global___VLANSubinterface] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ip_address", b"ip_address", "mac_limit", b"mac_limit", "native_subnet_id", b"native_subnet_id", "vlan_subinterfaces", b"vlan_subinterfaces"]) -> None: ...

global___PrivateNetworkInterface = PrivateNetworkInterface

@typing.final
class VLANSubinterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAGGED_SUBNET_ID_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    MAC_LIMIT_FIELD_NUMBER: builtins.int
    tagged_subnet_id: builtins.str
    """ID of the private subnet which is used as tagged subnet for interface."""
    ip_address: builtins.str
    """IPv4 address that is assigned to the VLAN subinterface.

    Read only field.
    """
    mac_limit: builtins.int
    """Limit of MAC addresses in the tagged subnet.

    Read only field.
    """
    def __init__(
        self,
        *,
        tagged_subnet_id: builtins.str = ...,
        ip_address: builtins.str = ...,
        mac_limit: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ip_address", b"ip_address", "mac_limit", b"mac_limit", "tagged_subnet_id", b"tagged_subnet_id"]) -> None: ...

global___VLANSubinterface = VLANSubinterface

@typing.final
class PublicNetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class NativeSubnet(google.protobuf.message.Message):
        """Configuration for using existing native subnet."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SUBNET_ID_FIELD_NUMBER: builtins.int
        subnet_id: builtins.str
        """ID of the existing public subnet."""
        def __init__(
            self,
            *,
            subnet_id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id"]) -> None: ...

    @typing.final
    class NewNativeSubnet(google.protobuf.message.Message):
        """Configuration for creating new native subnet."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _AddressingType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _AddressingTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PublicNetworkInterface.NewNativeSubnet._AddressingType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            ADDRESSING_TYPE_UNSPECIFIED: PublicNetworkInterface.NewNativeSubnet._AddressingType.ValueType  # 0
            """Unspecified public subnet addressing type."""
            DHCP: PublicNetworkInterface.NewNativeSubnet._AddressingType.ValueType  # 1
            """DHCP addressing."""
            STATIC: PublicNetworkInterface.NewNativeSubnet._AddressingType.ValueType  # 2
            """Static addressing."""

        class AddressingType(_AddressingType, metaclass=_AddressingTypeEnumTypeWrapper):
            """Addressing type for public subnet."""

        ADDRESSING_TYPE_UNSPECIFIED: PublicNetworkInterface.NewNativeSubnet.AddressingType.ValueType  # 0
        """Unspecified public subnet addressing type."""
        DHCP: PublicNetworkInterface.NewNativeSubnet.AddressingType.ValueType  # 1
        """DHCP addressing."""
        STATIC: PublicNetworkInterface.NewNativeSubnet.AddressingType.ValueType  # 2
        """Static addressing."""

        ADDRESSING_TYPE_FIELD_NUMBER: builtins.int
        addressing_type: global___PublicNetworkInterface.NewNativeSubnet.AddressingType.ValueType
        """Addressing type (DHCP | Static)."""
        def __init__(
            self,
            *,
            addressing_type: global___PublicNetworkInterface.NewNativeSubnet.AddressingType.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["addressing_type", b"addressing_type"]) -> None: ...

    IP_ADDRESS_FIELD_NUMBER: builtins.int
    NATIVE_SUBNET_ID_FIELD_NUMBER: builtins.int
    MAC_LIMIT_FIELD_NUMBER: builtins.int
    NATIVE_SUBNET_FIELD_NUMBER: builtins.int
    NEW_NATIVE_SUBNET_FIELD_NUMBER: builtins.int
    ip_address: builtins.str
    """IPv4 address that is assigned to the server for this network interface.

    Read only field.
    """
    native_subnet_id: builtins.str
    """ID of the public subnet which is used as native subnet for interface.

    Read only field.
    """
    mac_limit: builtins.int
    """Limit of MAC addresses in the native subnet.

    Read only field.
    """
    @property
    def native_subnet(self) -> global___PublicNetworkInterface.NativeSubnet:
        """Use existing native subnet.

        Input only field.
        """

    @property
    def new_native_subnet(self) -> global___PublicNetworkInterface.NewNativeSubnet:
        """Create new native subnet.

        Input only field.
        """

    def __init__(
        self,
        *,
        ip_address: builtins.str = ...,
        native_subnet_id: builtins.str = ...,
        mac_limit: builtins.int = ...,
        native_subnet: global___PublicNetworkInterface.NativeSubnet | None = ...,
        new_native_subnet: global___PublicNetworkInterface.NewNativeSubnet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["native_subnet", b"native_subnet", "native_subnet_config", b"native_subnet_config", "new_native_subnet", b"new_native_subnet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ip_address", b"ip_address", "mac_limit", b"mac_limit", "native_subnet", b"native_subnet", "native_subnet_config", b"native_subnet_config", "native_subnet_id", b"native_subnet_id", "new_native_subnet", b"new_native_subnet"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["native_subnet_config", b"native_subnet_config"]) -> typing.Literal["native_subnet", "new_native_subnet"] | None: ...

global___PublicNetworkInterface = PublicNetworkInterface

@typing.final
class PrivateSubnetNetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_SUBNET_ID_FIELD_NUMBER: builtins.int
    private_subnet_id: builtins.str
    """ID of the private subnet."""
    def __init__(
        self,
        *,
        private_subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_subnet_id", b"private_subnet_id"]) -> None: ...

global___PrivateSubnetNetworkInterface = PrivateSubnetNetworkInterface

@typing.final
class PublicSubnetNetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLIC_SUBNET_ID_FIELD_NUMBER: builtins.int
    public_subnet_id: builtins.str
    """ID of the public subnet.

    A new ephemeral public subnet will be created if not specified.
    """
    def __init__(
        self,
        *,
        public_subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["public_subnet_id", b"public_subnet_id"]) -> None: ...

global___PublicSubnetNetworkInterface = PublicSubnetNetworkInterface

@typing.final
class OsSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    SSH_PUBLIC_KEY_FIELD_NUMBER: builtins.int
    STORAGES_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the image that the server was created from."""
    ssh_public_key: builtins.str
    """Public SSH key of the server."""
    @property
    def storages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.storage_pb2.Storage]:
        """List of storages."""

    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
        ssh_public_key: builtins.str = ...,
        storages: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.storage_pb2.Storage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id", "ssh_public_key", b"ssh_public_key", "storages", b"storages"]) -> None: ...

global___OsSettings = OsSettings
